logscroll 0.2.4

Provide a limited window for logs
logscroll-0.2.4 is not a library.

Logscroll Build Status

Provide a limited window for logs

Installation

You could download the latest binary from the releases page or install it using cargo:

cargo install logscroll

Usage

You can just pipe any log to logscroll. It also accepts two optional args <height> and <width>

log_generating_command | logscroll <height> <width>

When it is not running using a tty, it just forewords the logs.